@@ -14,12 +14,12 @@
    @author Mark Seligman
  */
 
-#ifndef CART_RUNSET_H
-#define CART_RUNSET_H
+#ifndef SPLIT_RUNSET_H
+#define SPLIT_RUNSET_H
 
 #include <vector>
 
-#include "typeparam.h"
+#include "pretree.h"
 #include "sumcount.h"
 
 /**
@@ -37,8 +37,7 @@ class FRNode {
   double sum; // Sum of responses associated with run.
   IndexRange range;
 
-  FRNode() : sCount(0), sum(0.0) {
-    range.set(0, 0);
+  FRNode() : sCount(0), sum(0.0), range(IndexRange()) {
   }
 
   bool isImplicit();
@@ -55,7 +54,7 @@ class FRNode {
     this->rank = rank;
     this->sCount = sCount;
     this->sum = sum;
-    this->range.set(start, extent);
+    this->range = IndexRange(start, extent);
   }
 
   
@@ -186,7 +185,7 @@ class RunSet {
 
      @param ctgSum is the per-category response over the node (IndexSet).
   */
-  void writeImplicit(const class SplitCand* cand,
+  void writeImplicit(const class SplitNux* cand,
                      const class SplitFrontier* sp,
                      const vector<double>& ctgSum = vector<double>(0));
 
@@ -199,7 +198,7 @@ class RunSet {
 
      @return post-shrink run count.
   */
-  unsigned int deWide(unsigned int nCtg);
+  unsigned int deWide(PredictorT nCtg);
 
   /**
      @brief Depopulates the heap associated with a pair and places sorted ranks into rank vector.
@@ -216,7 +215,7 @@ class RunSet {
               vector<BHPair> &bHeap,
               vector<unsigned int> &lhOut,
               vector<double> &ctgSum,
-              unsigned int nCtg,
+              PredictorT nCtg,
               vector<double> &rvWide);
 
   /**
@@ -259,8 +258,7 @@ class RunSet {
   double branch(class IndexSet* iSet,
                 class PreTree* preTree,
                 const class SplitFrontier* splitFrontier,
-                class BV* bvLeft,
-                class BV* bvRight,
+		class Replay* replay,
                 vector<SumCount>& ctgCrit,
                 bool& replayLeft) const;
 
@@ -272,7 +270,7 @@ class RunSet {
 
      @param runIdx is the run index.
    */
-  void residCtg(unsigned int nCtg,
+  void residCtg(PredictorT nCtg,
                 unsigned int runIdx);
 
 
@@ -302,7 +300,7 @@ class RunSet {
 
      @return effective run count
    */
-  inline unsigned int effCount() const {
+  inline PredictorT effCount() const {
     return runCount > maxWidth ? maxWidth : runCount;
   }
 
@@ -324,7 +322,7 @@ class RunSet {
   /**
      @brief Sets run parameters and increments run count.
    */
-  inline void write(unsigned int rank,
+  inline void write(PredictorT rank,
                     IndexT sCount,
                     double sum,
                     IndexT extent,
@@ -340,9 +338,9 @@ class RunSet {
 
      @return void.
    */
-  inline void accumCtg(unsigned int nCtg,
+  inline void accumCtg(PredictorT nCtg,
                        double ySum,
-                       unsigned int yCtg) {
+                       PredictorT yCtg) {
     ctgZero[runCount * nCtg + yCtg] += ySum;
   }
 
@@ -350,7 +348,9 @@ class RunSet {
   /**
      @return checkerboard value at slot for category.
    */
-  inline double getSumCtg(unsigned int slot, unsigned int nCtg, unsigned int yCtg) const {
+  inline double getSumCtg(PredictorT slot,
+			  PredictorT nCtg,
+			  PredictorT yCtg) const {
     return ctgZero[slot * nCtg + yCtg];
   }
 
@@ -367,7 +367,9 @@ class RunSet {
 
      @return true iff slot counts differ by at least unity.
    */
-  inline bool accumBinary(unsigned int outPos, double &sum0, double &sum1) {
+  inline bool accumBinary(unsigned int outPos,
+			  double& sum0,
+			  double& sum1) {
     unsigned int slot = outZero[outPos];
     double cell0 = getSumCtg(slot, 2, 0);
     sum0 += cell0;
@@ -419,7 +421,7 @@ class RunSet {
 
      @return LHS index count.
   */
-  unsigned int lHBits(unsigned int lhBits, unsigned int &lhSampCt);
+  IndexT lHBits(unsigned int lhBits, IndexT& lhSampCt);
   
   /**
      @brief Dereferences out slots and accumulates splitting parameters.
@@ -430,7 +432,7 @@ class RunSet {
 
      @return LHS index count.
   */
-  unsigned int lHSlots(unsigned int outPos, unsigned int &lhSampCt);
+  unsigned int lHSlots(unsigned int outPos, IndexT& lhSampCt);
 
   /**
      @brief Looks up run parameters by indirection through output vector.
@@ -517,8 +519,7 @@ public:
   double branch(const class SplitFrontier* splitFrontier,
                 class IndexSet* iSet,
                 class PreTree* preTree,
-                class BV* bvLeft,
-                class BV* bvRight,
+		class Replay* replay,
                 vector<SumCount>& ctgCrit,
                 bool& replayLeft) const;
 
