@@ -17,7 +17,6 @@
 #include "bv.h"
 #include "callback.h"
 #include "summaryframe.h"
-#include "splitfrontier.h"
 #include "obspart.h"
 
 // Simulation-invariant values.
@@ -144,11 +143,6 @@ void SampleReg::bagSamples(const double y[], BV *treeBag) {
 }
 
 
-unique_ptr<SplitFrontier> SampleReg::frontierFactory(const SummaryFrame* frame, class Frontier* frontier) const {
-  return make_unique<SFReg>(frame, frontier, this);
-}
-
-
 SampleCtg::SampleCtg(const SummaryFrame* frame) : Sample(frame) {
   SumCount scZero;
   fill(ctgRoot.begin(), ctgRoot.end(), scZero);
@@ -163,11 +157,6 @@ void SampleCtg::bagSamples(const unsigned int yCtg[], const double y[], BV *tree
 }
 
 
-unique_ptr<SplitFrontier> SampleCtg::frontierFactory(const SummaryFrame* frame, class Frontier* frontier) const {
-  return make_unique<SFCtg>(frame, frontier, this, SampleNux::getNCtg());
-}
-
-
 void Sample::bagSamples(const double y[], const unsigned int yCtg[], BV *treeBag) {
   // Samples row indices and counts occurrences.
   //
